==> haskell-simple-sendfile-0.2.32-155-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-YLUBZjYdN6A0x29aDBll1
key:                  simple-sendfile-0.2.32-YLUBZjYdN6A0x29aDBll1
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  3c409786218823ac2aa0bd58ee34f442
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-YLUBZjYdN6A0x29aDBll1
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-DD61ZgteIR5Dyq0QRyt6FX unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.32-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-6wrHHLuUXzi23w3lgNIAdp
key:                  simple-sendfile-0.2.32-6wrHHLuUXzi23w3lgNIAdp
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  ecd13e0fec8f1e1128cc29a763ca6df6
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-6wrHHLuUXzi23w3lgNIAdp
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-7upd0S3IeIT8lWw9Gu9EjE unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
